# vitest

[![NPM version](https://img.shields.io/npm/v/vitest?color=a1b858&label=)](https://www.npmjs.com/package/vitest)

Next generation testing framework powered by Vite.

[GitHub](https://github.com/vitest-dev/vitest) | [Documentation](https://vitest.dev/)
